/* Generated by Nim Compiler v2.2.10 */
#define NIM_INTBITS 64
#define NIM_EmulateOverflowChecks

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
typedef struct tySequence__4SBkVvm2CCxNvzruVhJR5g tySequence__4SBkVvm2CCxNvzruVhJR5g;
typedef struct tySequence__4SBkVvm2CCxNvzruVhJR5g_Content tySequence__4SBkVvm2CCxNvzruVhJR5g_Content;
typedef struct tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg;
typedef struct tySequence__5reviU45axUMPQgL9aoENrg tySequence__5reviU45axUMPQgL9aoENrg;
typedef struct tySequence__5reviU45axUMPQgL9aoENrg_Content tySequence__5reviU45axUMPQgL9aoENrg_Content;
typedef struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg;
typedef struct tyObject_AliveContext__aH9b1WgJ8tkMKZF7vl3FOBw tyObject_AliveContext__aH9b1WgJ8tkMKZF7vl3FOBw;
typedef struct tySequence__MboA857W9b3olvEyCWLQeEg tySequence__MboA857W9b3olvEyCWLQeEg;
typedef struct tySequence__MboA857W9b3olvEyCWLQeEg_Content tySequence__MboA857W9b3olvEyCWLQeEg_Content;
typedef struct tyObject_PackedDecoder__mXpMPUjuhwIS5ssrGM9bHWA tyObject_PackedDecoder__mXpMPUjuhwIS5ssrGM9bHWA;
typedef struct tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA;
typedef struct tyObject_Table__t60gWhquDic6PI6CgxHkgw tyObject_Table__t60gWhquDic6PI6CgxHkgw;
typedef struct tySequence__UuiPn6QjIiUTdSVwX2PZ6w tySequence__UuiPn6QjIiUTdSVwX2PZ6w;
typedef struct tySequence__UuiPn6QjIiUTdSVwX2PZ6w_Content tySequence__UuiPn6QjIiUTdSVwX2PZ6w_Content;
typedef struct tyTuple__jYR27AKllNE6EvJCKQs1WA tyTuple__jYR27AKllNE6EvJCKQs1WA;
typedef struct tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA;
typedef struct NimStrPayload NimStrPayload;
typedef struct NimStringV2 NimStringV2;
typedef struct tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg;
typedef struct tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw;
typedef struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA tySequence__E0kio2ZnplNTuln9bsnljSA;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content tySequence__E0kio2ZnplNTuln9bsnljSA_Content;
typedef struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content tySequence__7lEisrXlQEzwtUKW5pzRCw_Content;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA tySequence__hTEiKNj3evQAjIXUI21elA;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA_Content tySequence__hTEiKNj3evQAjIXUI21elA_Content;
typedef struct tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw_Content tySequence__4eRCaZmrYLLw2k30GPTiMw_Content;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content;
typedef struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q tySequence__xOJ2kx2lq9bBfIm3IXnde3Q;
typedef struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content;
typedef struct tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA;
typedef struct tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ;
typedef struct tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA;
typedef struct tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA tySequence__PXIzfWocnrafGz5p3CP5LA;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA_Content tySequence__PXIzfWocnrafGz5p3CP5LA_Content;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA tySequence__9bAGqSvkAaFL9bWjsEPslrFA;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content;
typedef struct tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w;
typedef struct tySequence__OxRbUT0qZaZN5UjnqQjGPA tySequence__OxRbUT0qZaZN5UjnqQjGPA;
typedef struct tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content;
typedef struct tySequence__ezS5mGPcRfBURJyMgqYVzA tySequence__ezS5mGPcRfBURJyMgqYVzA;
typedef struct tySequence__ezS5mGPcRfBURJyMgqYVzA_Content tySequence__ezS5mGPcRfBURJyMgqYVzA_Content;
typedef struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA tySequence__wW7xkohjuUKO9aMaB0nt9cqA;
typedef struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg tySequence__b89aLriiJnVTD186H6zNIgg;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg_Content tySequence__b89aLriiJnVTD186H6zNIgg_Content;
typedef struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg tySequence__hIPTk9aFdaMMVAOzEbnPyqg;
typedef struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA_Content tySequence__48JTohSgTy339bRxHzUD8KA_Content;
typedef struct tySequence__YYy1721YAuPF0ajBYHd8Wg tySequence__YYy1721YAuPF0ajBYHd8Wg;
typedef struct tySequence__YYy1721YAuPF0ajBYHd8Wg_Content tySequence__YYy1721YAuPF0ajBYHd8Wg_Content;
typedef struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ tySequence__UODJbvzmu39c3Ho9cqhSk9agQ;
typedef struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content;
typedef struct tySequence__F1qNdU7m0Czu7Y2q0eksXw tySequence__F1qNdU7m0Czu7Y2q0eksXw;
typedef struct tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content;
typedef struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q tySequence__r3Kz9breImOXyFFoJ29aBM8Q;
typedef struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content;
typedef struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw tySequence__qBes3XzcQQ9cyia9bRwnmbJw;
typedef struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content;
typedef struct tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw;
typedef struct tySequence__Vl1abU3gfp0RqCb1KKfmDA tySequence__Vl1abU3gfp0RqCb1KKfmDA;
typedef struct tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content;
typedef struct tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw;
typedef struct tySequence__qyyNkmlc4fzOzelC8spUkQ tySequence__qyyNkmlc4fzOzelC8spUkQ;
typedef struct tySequence__qyyNkmlc4fzOzelC8spUkQ_Content tySequence__qyyNkmlc4fzOzelC8spUkQ_Content;
typedef struct tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA;
typedef struct tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ tySequence__IHUFRsFxZNv7YydiUO2esQ;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ_Content tySequence__IHUFRsFxZNv7YydiUO2esQ_Content;
typedef struct tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ;
typedef struct tySequence__orxtl6CusdjXleqrxi67gw tySequence__orxtl6CusdjXleqrxi67gw;
typedef struct tySequence__orxtl6CusdjXleqrxi67gw_Content tySequence__orxtl6CusdjXleqrxi67gw_Content;
typedef struct tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ;
typedef struct tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ;
typedef struct tySequence__K0j67V58u5FW0dCC534FQw tySequence__K0j67V58u5FW0dCC534FQw;
typedef struct tySequence__K0j67V58u5FW0dCC534FQw_Content tySequence__K0j67V58u5FW0dCC534FQw_Content;
typedef struct tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ;
typedef struct tySequence__UE4b6iUkm1b3zTPamTTkDw tySequence__UE4b6iUkm1b3zTPamTTkDw;
typedef struct tySequence__UE4b6iUkm1b3zTPamTTkDw_Content tySequence__UE4b6iUkm1b3zTPamTTkDw_Content;
typedef struct tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg;
typedef struct tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg;
typedef struct tySequence__FmsTQiIcS9arxHxs3QY48vA tySequence__FmsTQiIcS9arxHxs3QY48vA;
typedef struct tySequence__FmsTQiIcS9arxHxs3QY48vA_Content tySequence__FmsTQiIcS9arxHxs3QY48vA_Content;
typedef struct tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w;
typedef struct tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA;
typedef struct tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA;
typedef struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA tySequence__ZeWVlH6DqG79b1pTDhrrUYA;
typedef struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content;
typedef struct tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw;
typedef struct tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig;
typedef struct tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg;
typedef struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ;
typedef struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA;
typedef struct tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ;
typedef struct tyTuple__Ll5iolPASSzOEheeSNjmiw tyTuple__Ll5iolPASSzOEheeSNjmiw;
typedef struct tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A;
typedef struct tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA;
typedef struct tyTuple__9a3DhYVfcy14Fx42tD0lSEQ tyTuple__9a3DhYVfcy14Fx42tD0lSEQ;
typedef struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg;
typedef struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q tyTuple__0q9cmhneJEKnQERTpXXdz6Q;
typedef struct tyTuple__48iPM3yLBKU5nyEuYwJvuQ tyTuple__48iPM3yLBKU5nyEuYwJvuQ;
typedef struct tyTuple__R3ddFrA0G9buJY57Qhf9cTpg tyTuple__R3ddFrA0G9buJY57Qhf9cTpg;
typedef struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ;
typedef struct tyTuple__7rmdAMLZ8fDd79brQn2ixZA tyTuple__7rmdAMLZ8fDd79brQn2ixZA;
typedef struct tyTuple__qPXRCRNQuZLLKto7CIIEzw tyTuple__qPXRCRNQuZLLKto7CIIEzw;
typedef struct tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg;
typedef struct tyTuple__6kG8KAxm9aXPdLdlxcxqJJw tyTuple__6kG8KAxm9aXPdLdlxcxqJJw;
typedef struct tyTuple__TRK7rrwoha9bbDAdPWsqJMw tyTuple__TRK7rrwoha9bbDAdPWsqJMw;
typedef struct tyTuple__V1VWX9bHapuzCjpMfFfys5Q tyTuple__V1VWX9bHapuzCjpMfFfys5Q;
typedef struct tyTuple__anemVmHCFglLFt6LiEhFvg tyTuple__anemVmHCFglLFt6LiEhFvg;
typedef struct tyTuple__MaWaKZwaGUqCXKsSK12rVg tyTuple__MaWaKZwaGUqCXKsSK12rVg;
typedef struct tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA;
typedef struct tyTuple__1xWeGeoNoZxaLhTUDDWYyA tyTuple__1xWeGeoNoZxaLhTUDDWYyA;
typedef struct tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg;
typedef struct tyTuple__MZVSn3SE3XUBJOaMu7ofRQ tyTuple__MZVSn3SE3XUBJOaMu7ofRQ;
struct tySequence__4SBkVvm2CCxNvzruVhJR5g {
  NI len; tySequence__4SBkVvm2CCxNvzruVhJR5g_Content* p;
};
struct tySequence__5reviU45axUMPQgL9aoENrg {
  NI len; tySequence__5reviU45axUMPQgL9aoENrg_Content* p;
};
struct tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg {
	tySequence__5reviU45axUMPQgL9aoENrg pm;
};
struct tySequence__MboA857W9b3olvEyCWLQeEg {
  NI len; tySequence__MboA857W9b3olvEyCWLQeEg_Content* p;
};
struct tyObject_PackedDecoder__mXpMPUjuhwIS5ssrGM9bHWA {
	NI lastModule;
	NU32 lastLit;
	NI32 lastFile;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config;
	tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache;
};
typedef NU32 tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ;
struct tySequence__UuiPn6QjIiUTdSVwX2PZ6w {
  NI len; tySequence__UuiPn6QjIiUTdSVwX2PZ6w_Content* p;
};
struct tyObject_Table__t60gWhquDic6PI6CgxHkgw {
	tySequence__UuiPn6QjIiUTdSVwX2PZ6w data;
	NI counter;
};
struct tyObject_AliveContext__aH9b1WgJ8tkMKZF7vl3FOBw {
	tySequence__MboA857W9b3olvEyCWLQeEg stack;
	tyObject_PackedDecoder__mXpMPUjuhwIS5ssrGM9bHWA decoder;
	NI thisModule;
	tySequence__4SBkVvm2CCxNvzruVhJR5g alive;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tyObject_Table__t60gWhquDic6PI6CgxHkgw compilerProcs;
};
struct tyTuple__jYR27AKllNE6EvJCKQs1WA {
	NI Field0;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ Field1;
	NI Field2;
};
typedef NU8 tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw;
typedef NU8 tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw;
typedef NU8 tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw;
struct NimStrPayload {
	NI cap;
	NIM_CHAR data[SEQ_DECL_SIZE];
};
struct NimStringV2 {
	NI len;
	NimStrPayload* p;
};
struct tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA {
	tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw targetCPU;
	tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw hostCPU;
	tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw targetOS;
	tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw hostOS;
	NI intSize;
	NI floatSize;
	NI ptrSize;
	NimStringV2 tnl;
};
typedef NU64 tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A;
struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA {
	NU16 line;
	NI16 col;
	NI32 fileIndex;
};
typedef NU8 tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw;
struct tySequence__E0kio2ZnplNTuln9bsnljSA {
  NI len; tySequence__E0kio2ZnplNTuln9bsnljSA_Content* p;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  NI len; tySequence__7lEisrXlQEzwtUKW5pzRCw_Content* p;
};
struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A {
	tySequence__7lEisrXlQEzwtUKW5pzRCw data;
	NI counter;
};
struct tySequence__hTEiKNj3evQAjIXUI21elA {
  NI len; tySequence__hTEiKNj3evQAjIXUI21elA_Content* p;
};
struct tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA trackPos;
	NIM_BOOL trackPosAttached;
	tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw errorOutputs;
	tySequence__E0kio2ZnplNTuln9bsnljSA msgContext;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastError;
	tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A filenameToIndexTbl;
	tySequence__hTEiKNj3evQAjIXUI21elA fileInfos;
	NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ;
typedef NU8 tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ;
typedef NU8 tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg;
typedef NU8 tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw;
typedef NU8 tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA;
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  NI len; tySequence__4eRCaZmrYLLw2k30GPTiMw_Content* p;
};
struct tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw {
	tySequence__4eRCaZmrYLLw2k30GPTiMw data;
	NI counter;
};
typedef NU32 tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ;
typedef NU8 tySet_tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA;
typedef NU8 tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng;
typedef NU8 tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA;
typedef NU8 tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw[13];
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  NI len; tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content* p;
};
typedef NU8 tySet_tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw;
struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q {
  NI len; tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content* p;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* result_p0, void* ClE_0);
void* ClE_0;
} tyProc__QQyR5yGA47tr5TwLxcC4Gw;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringV2 output_p0, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 msg_p2, tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA severity_p3, void* ClE_0);
void* ClE_0;
} tyProc__DA9aR62IikoxFqfC5rIT9cuw;
struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg {
	tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend;
	tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA target;
	NI linesCompiled;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A globalOptions;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* macrosToExpand;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* arcToExpand;
	tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw m;
	tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ filenameOption;
	NimStringV2 unitSep;
	NI evalTemplateCounter;
	NI evalMacroCounter;
	NI8 exitcode;
	tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ cmd;
	NimStringV2 cmdInput;
	NIM_BOOL projectIsCmd;
	NIM_BOOL implicitCmd;
	tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg selectedGC;
	tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw exc;
	NIM_BOOL hintProcessingDots;
	NI verbosity;
	NI numberOfProcessors;
	NF lastCmdTime;
	tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA symbolFiles;
	NI spellSuggestMax;
	tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw cppDefines;
	NimStringV2 headerFile;
	NimStringV2 nimbasePattern;
	tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ features;
	tySet_tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA legacyFeatures;
	NimStringV2 arguments;
	tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng ideCmd;
	tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA cCompiler;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw modifiedyNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw cmdlineNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw foreignPackageNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw notes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw warningAsErrors;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw mainPackageNotes;
	NI mainPackageId;
	NI errorCounter;
	NI hintCounter;
	NI warnCounter;
	NI errorMax;
	NI maxLoopIterationsVM;
	NI maxCallDepthVM;
	NIM_BOOL isVmTrace;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* configVars;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* symbols;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* packageCache;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ nimblePaths;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ searchPaths;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ lazyPaths;
	NimStringV2 outFile;
	NimStringV2 outDir;
	NimStringV2 jsonBuildFile;
	NimStringV2 prefixDir;
	NimStringV2 libpath;
	NimStringV2 nimcacheDir;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* dllOverrides;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* moduleOverrides;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* cfileSpecificOptions;
	NimStringV2 projectName;
	NimStringV2 projectPath;
	NimStringV2 projectFull;
	NIM_BOOL projectIsStdin;
	NimStringV2 stdinFile;
	tySet_tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw lastMsgWasDot;
	NI32 projectMainIdx;
	NI32 projectMainIdx2;
	NimStringV2 command;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ commandArgs;
	NimStringV2 commandLine;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ extraCmds;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ implicitImports;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ implicitIncludes;
	NimStringV2 docSeeSrcUrl;
	NimStringV2 docRoot;
	NimStringV2 docCmd;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ configFiles;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cIncludes;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cLibs;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cLinkedLibs;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ externalToLink;
	NimStringV2 linkOptionsCmd;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ compileOptionsCmd;
	NimStringV2 linkOptions;
	NimStringV2 compileOptions;
	NimStringV2 cCompilerPath;
	tySequence__xOJ2kx2lq9bBfIm3IXnde3Q toCompile;
	tyProc__QQyR5yGA47tr5TwLxcC4Gw suggestionResultHook;
	NI suggestVersion;
	NI suggestMaxResults;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastLineInfo;
	tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
	tyProc__DA9aR62IikoxFqfC5rIT9cuw structuredErrorHook;
	NimStringV2 cppCustomNamespace;
	NimStringV2 nimMainPrefix;
	tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ* vmProfileData;
	NIM_BOOL expandProgress;
	NI expandLevels;
	NimStringV2 expandNodeResult;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA expandPosition;
	NimStringV2 currentConfigDir;
	NI clientProcessId;
};
typedef NU8 tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ;
typedef NU64 tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg;
struct tySequence__PXIzfWocnrafGz5p3CP5LA {
  NI len; tySequence__PXIzfWocnrafGz5p3CP5LA_Content* p;
};
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA {
  NI len; tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content* p;
};
struct tySequence__OxRbUT0qZaZN5UjnqQjGPA {
  NI len; tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content* p;
};
struct tySequence__ezS5mGPcRfBURJyMgqYVzA {
  NI len; tySequence__ezS5mGPcRfBURJyMgqYVzA_Content* p;
};
struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA {
  NI len; tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content* p;
};
struct tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w {
	tySequence__OxRbUT0qZaZN5UjnqQjGPA nodes;
	tySequence__ezS5mGPcRfBURJyMgqYVzA withFlags;
	tySequence__wW7xkohjuUKO9aMaB0nt9cqA withTypes;
};
struct tySequence__b89aLriiJnVTD186H6zNIgg {
  NI len; tySequence__b89aLriiJnVTD186H6zNIgg_Content* p;
};
struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg {
  NI len; tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content* p;
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  NI len; tySequence__48JTohSgTy339bRxHzUD8KA_Content* p;
};
struct tySequence__YYy1721YAuPF0ajBYHd8Wg {
  NI len; tySequence__YYy1721YAuPF0ajBYHd8Wg_Content* p;
};
struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ {
  NI len; tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content* p;
};
struct tySequence__F1qNdU7m0Czu7Y2q0eksXw {
  NI len; tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content* p;
};
struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q {
  NI len; tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content* p;
};
struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw {
  NI len; tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content* p;
};
typedef NU8 tySet_tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ;
struct tySequence__Vl1abU3gfp0RqCb1KKfmDA {
  NI len; tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content* p;
};
struct tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw {
	tySequence__Vl1abU3gfp0RqCb1KKfmDA data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__qyyNkmlc4fzOzelC8spUkQ {
  NI len; tySequence__qyyNkmlc4fzOzelC8spUkQ_Content* p;
};
struct tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw {
	tySequence__qyyNkmlc4fzOzelC8spUkQ data;
	NI counter;
	NI first;
	NI last;
};
struct tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA {
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ vals;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA keys;
};
struct tySequence__IHUFRsFxZNv7YydiUO2esQ {
  NI len; tySequence__IHUFRsFxZNv7YydiUO2esQ_Content* p;
};
struct tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg {
	tySequence__IHUFRsFxZNv7YydiUO2esQ vals;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA keys;
};
struct tySequence__orxtl6CusdjXleqrxi67gw {
  NI len; tySequence__orxtl6CusdjXleqrxi67gw_Content* p;
};
struct tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ {
	tySequence__orxtl6CusdjXleqrxi67gw aside;
};
struct tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ {
	tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend;
	tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg selectedGC;
	tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA cCompiler;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A globalOptions;
};
struct tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ {
	NimStringV2 definedSymbols;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg moduleFlags;
	tySequence__PXIzfWocnrafGz5p3CP5LA includes;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA imports;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w toReplay;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w topLevel;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w bodies;
	tySequence__b89aLriiJnVTD186H6zNIgg exports;
	tySequence__b89aLriiJnVTD186H6zNIgg hidden;
	tySequence__hIPTk9aFdaMMVAOzEbnPyqg reexports;
	tySequence__b89aLriiJnVTD186H6zNIgg compilerProcs;
	tySequence__48JTohSgTy339bRxHzUD8KA converters;
	tySequence__48JTohSgTy339bRxHzUD8KA methods;
	tySequence__48JTohSgTy339bRxHzUD8KA trmacros;
	tySequence__48JTohSgTy339bRxHzUD8KA pureEnums;
	tySequence__YYy1721YAuPF0ajBYHd8Wg typeInstCache;
	tySequence__UODJbvzmu39c3Ho9cqhSk9agQ procInstCache;
	tySequence__F1qNdU7m0Czu7Y2q0eksXw attachedOps;
	tySequence__r3Kz9breImOXyFFoJ29aBM8Q methodsPerGenericType;
	tySequence__YYy1721YAuPF0ajBYHd8Wg enumToStringProcs;
	tySequence__YYy1721YAuPF0ajBYHd8Wg methodsPerType;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw dispatchers;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ emittedTypeInfo;
	tySet_tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ backendFlags;
	tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw syms;
	tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw types;
	tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA strings;
	tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg numbers;
	tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ man;
	tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ cfg;
};
struct tySequence__K0j67V58u5FW0dCC534FQw {
  NI len; tySequence__K0j67V58u5FW0dCC534FQw_Content* p;
};
struct tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ {
	tySequence__K0j67V58u5FW0dCC534FQw data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__UE4b6iUkm1b3zTPamTTkDw {
  NI len; tySequence__UE4b6iUkm1b3zTPamTTkDw_Content* p;
};
struct tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ {
	tySequence__UE4b6iUkm1b3zTPamTTkDw data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__FmsTQiIcS9arxHxs3QY48vA {
  NI len; tySequence__FmsTQiIcS9arxHxs3QY48vA_Content* p;
};
struct tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg {
	tySequence__FmsTQiIcS9arxHxs3QY48vA data;
	NI counter;
};
struct tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA {
	tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ status;
	NIM_BOOL symsInit;
	NIM_BOOL typesInit;
	NIM_BOOL loadedButAliveSetChanged;
	tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ fromDisk;
	tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ syms;
	tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ types;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg iface;
	tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg ifaceHidden;
};
struct tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w {
	NU32 x;
	NU32 info;
};
typedef NU8 tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw;
struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA {
  NI len; tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content* p;
};
typedef NI tyArray__k7D0lwfLmYccbQxUd49bbcQ[34];
struct tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA {
	NI elems;
	NI counter;
	NI max;
	tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* head;
	tySequence__ZeWVlH6DqG79b1pTDhrrUYA data;
	tyArray__k7D0lwfLmYccbQxUd49bbcQ a;
};
typedef NU8 tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q;
struct tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig {
	NU32 module;
	NI32 item;
};
typedef NU16 tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg;
typedef NU16 tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg;
typedef NU8 tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A;
struct tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg {
	tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A kind;
	NIM_BOOL generated;
	NIM_BOOL isOverridden;
	NU32 name;
	NI32 path;
};
struct tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw {
	NI32 id;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind;
	NU32 name;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig typ;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flags;
	tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg magic;
	NU32 info;
	NI32 ast;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig owner;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig guard;
	NI bitsize;
	NI alignment;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	NI position;
	NI32 offset;
	NI32 disamb;
	NU32 externalName;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg locFlags;
	tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg annex;
	NI32 constraint;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig instantiatedFrom;
};
struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ {
	NI Field0;
	NI Field1;
};
typedef NU8 tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg;
typedef NU8 tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg[9];
struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA {
	NI32 module;
	NI32 item;
};
typedef NU8 tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ;
typedef NU64 tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A;
struct tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ {
	NI32 id;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind;
	tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ callConv;
	tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A flags;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw types;
	NI32 n;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig sym;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig owner;
	NI64 size;
	NI16 align;
	NI16 paddingAtEnd;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig typeInst;
	NI32 nonUniqueId;
};
typedef NU8 tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ;
struct tyTuple__Ll5iolPASSzOEheeSNjmiw {
	NI Field0;
	NI32 Field1;
};
typedef NU8 tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg;
struct tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A {
	NI rc;
	NI rootIdx;
};
typedef tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* tyArray__s9a2jZbmN9cnqFaNnzUrYEjg[8192];
struct tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA {
	tyArray__s9a2jZbmN9cnqFaNnzUrYEjg buckets;
	NI wordCounter;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* idAnon;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* idDelegator;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* emptyIdent;
};
struct tySequence__4SBkVvm2CCxNvzruVhJR5g_Content { NI cap; tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA data[SEQ_DECL_SIZE]; };
struct tySequence__5reviU45axUMPQgL9aoENrg_Content { NI cap; tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA data[SEQ_DECL_SIZE]; };
struct tySequence__MboA857W9b3olvEyCWLQeEg_Content { NI cap; tyTuple__jYR27AKllNE6EvJCKQs1WA data[SEQ_DECL_SIZE]; };
struct tyTuple__9a3DhYVfcy14Fx42tD0lSEQ {
	NI Field0;
	NimStringV2 Field1;
	tyTuple__Ll5iolPASSzOEheeSNjmiw Field2;
};
struct tySequence__UuiPn6QjIiUTdSVwX2PZ6w_Content { NI cap; tyTuple__9a3DhYVfcy14Fx42tD0lSEQ data[SEQ_DECL_SIZE]; };
struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA Field0;
	NimStringV2 Field1;
};
struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content { NI cap; tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ data[SEQ_DECL_SIZE]; };
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
	NI Field0;
	NimStringV2 Field1;
	NI32 Field2;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content { NI cap; tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE]; };
struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw {
	NimStringV2 fullPath;
	NimStringV2 projPath;
	NimStringV2 shortName;
	NimStringV2 quotedName;
	NimStringV2 quotedFullName;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ lines;
	NimStringV2 dirtyFile;
	NimStringV2 hash;
	NIM_BOOL dirty;
};
struct tySequence__hTEiKNj3evQAjIXUI21elA_Content { NI cap; tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw data[SEQ_DECL_SIZE]; };
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
	NI Field0;
	NimStringV2 Field1;
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw_Content { NI cap; tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE]; };
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content { NI cap; NimStringV2 data[SEQ_DECL_SIZE]; };
typedef NU8 tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ;
struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg {
	NimStringV2 nimname;
	NimStringV2 cname;
	NimStringV2 obj;
	tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ flags;
	NimStringV2 customArgs;
};
struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content { NI cap; tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg data[SEQ_DECL_SIZE]; };
struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q {
	NU32 Field0;
	NimStringV2 Field1;
};
struct tySequence__PXIzfWocnrafGz5p3CP5LA_Content { NI cap; tyTuple__0q9cmhneJEKnQERTpXXdz6Q data[SEQ_DECL_SIZE]; };
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content { NI cap; NU32 data[SEQ_DECL_SIZE]; };
struct tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content { NI cap; tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w data[SEQ_DECL_SIZE]; };
typedef NU32 tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw;
struct tyTuple__48iPM3yLBKU5nyEuYwJvuQ {
	NI32 Field0;
	tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw Field1;
};
struct tySequence__ezS5mGPcRfBURJyMgqYVzA_Content { NI cap; tyTuple__48iPM3yLBKU5nyEuYwJvuQ data[SEQ_DECL_SIZE]; };
struct tyTuple__R3ddFrA0G9buJY57Qhf9cTpg {
	NI32 Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content { NI cap; tyTuple__R3ddFrA0G9buJY57Qhf9cTpg data[SEQ_DECL_SIZE]; };
struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ {
	NU32 Field0;
	NI32 Field1;
};
struct tySequence__b89aLriiJnVTD186H6zNIgg_Content { NI cap; tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ data[SEQ_DECL_SIZE]; };
struct tyTuple__7rmdAMLZ8fDd79brQn2ixZA {
	NU32 Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content { NI cap; tyTuple__7rmdAMLZ8fDd79brQn2ixZA data[SEQ_DECL_SIZE]; };
struct tySequence__48JTohSgTy339bRxHzUD8KA_Content { NI cap; NI32 data[SEQ_DECL_SIZE]; };
struct tyTuple__qPXRCRNQuZLLKto7CIIEzw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__YYy1721YAuPF0ajBYHd8Wg_Content { NI cap; tyTuple__qPXRCRNQuZLLKto7CIIEzw data[SEQ_DECL_SIZE]; };
struct tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig key;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig sym;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw concreteTypes;
};
struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content { NI cap; tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg data[SEQ_DECL_SIZE]; };
typedef NU8 tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q;
struct tyTuple__6kG8KAxm9aXPdLdlxcxqJJw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q Field1;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field2;
};
struct tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content { NI cap; tyTuple__6kG8KAxm9aXPdLdlxcxqJJw data[SEQ_DECL_SIZE]; };
struct tyTuple__TRK7rrwoha9bbDAdPWsqJMw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	NI Field1;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field2;
};
struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content { NI cap; tyTuple__TRK7rrwoha9bbDAdPWsqJMw data[SEQ_DECL_SIZE]; };
struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content { NI cap; tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig data[SEQ_DECL_SIZE]; };
struct tyTuple__V1VWX9bHapuzCjpMfFfys5Q {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw Field3;
};
struct tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content { NI cap; tyTuple__V1VWX9bHapuzCjpMfFfys5Q data[SEQ_DECL_SIZE]; };
struct tyTuple__anemVmHCFglLFt6LiEhFvg {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ Field3;
};
struct tySequence__qyyNkmlc4fzOzelC8spUkQ_Content { NI cap; tyTuple__anemVmHCFglLFt6LiEhFvg data[SEQ_DECL_SIZE]; };
struct tySequence__IHUFRsFxZNv7YydiUO2esQ_Content { NI cap; NI64 data[SEQ_DECL_SIZE]; };
struct tyTuple__MaWaKZwaGUqCXKsSK12rVg {
	NU32 Field0;
	NI32 Field1;
	NI32 Field2;
};
struct tySequence__orxtl6CusdjXleqrxi67gw_Content { NI cap; tyTuple__MaWaKZwaGUqCXKsSK12rVg data[SEQ_DECL_SIZE]; };
struct tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field3;
};
struct tySequence__K0j67V58u5FW0dCC534FQw_Content { NI cap; tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA data[SEQ_DECL_SIZE]; };
struct tyTuple__1xWeGeoNoZxaLhTUDDWYyA {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field3;
};
struct tySequence__UE4b6iUkm1b3zTPamTTkDw_Content { NI cap; tyTuple__1xWeGeoNoZxaLhTUDDWYyA data[SEQ_DECL_SIZE]; };
struct tyTuple__MZVSn3SE3XUBJOaMu7ofRQ {
	NI Field0;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* Field1;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw Field2;
};
struct tySequence__FmsTQiIcS9arxHxs3QY48vA_Content { NI cap; tyTuple__MZVSn3SE3XUBJOaMu7ofRQ data[SEQ_DECL_SIZE]; };
struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content { NI cap; tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* data[SEQ_DECL_SIZE]; };
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1);
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqPayload)(NI cap_p0, NI elemSize_p1, NI elemAlign_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg*, eqdup___options_u2141)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* src_p0);
N_LIB_PRIVATE N_NIMCALL(tySequence__4SBkVvm2CCxNvzruVhJR5g, newSeq__icZdce_u2562)(NI len_p0);
static N_INLINE(NI, len__icZpacked95ast_u767)(tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w* tree_p0);
N_LIB_PRIVATE N_NIMCALL(void, aliveCode__icZdce_u2384)(tyObject_AliveContext__aH9b1WgJ8tkMKZF7vl3FOBw* c_p0, tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg g_p1, tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w* tree_p2, NI n_p3);
N_LIB_PRIVATE N_NIMCALL(void, followLater__icZdce_u1695)(tyObject_AliveContext__aH9b1WgJ8tkMKZF7vl3FOBw* c_p0, tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg g_p1, NI module_p2, NI32 item_p3);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsOrIncl__astyaml_u223)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* s_p0, NI key_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw*, X5BX5D___icZic_u300)(tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw* t_p0, NI32 key_p1);
N_LIB_PRIVATE N_NIMCALL(NI, ithSon__icZpacked95ast_u1185)(tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w* tree_p0, NI n_p1, NI i_p2);
N_LIB_PRIVATE N_NIMCALL(void, add__icZdce_u1890)(tySequence__MboA857W9b3olvEyCWLQeEg* x_p0, tyTuple__jYR27AKllNE6EvJCKQs1WA y_p1);
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void);
static N_INLINE(tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w*, X5BX5D___icZpacked95ast_u773)(tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w* tree_p0, NI i_p1);
N_LIB_PRIVATE N_NIMCALL(tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ, sons2__icZpacked95ast_u1125)(tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w* tree_p0, NI n_p1);
N_LIB_PRIVATE N_NIMCALL(NI32, toFileIndexCached__icZic_u12260)(tyObject_PackedDecoder__mXpMPUjuhwIS5ssrGM9bHWA* c_p0, tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg g_p1, NI thisModule_p2, NU32 f_p3);
static N_INLINE(void, nextChild__icZpacked95ast_u798)(tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w* tree_p0, NI* pos_p1);
N_LIB_PRIVATE N_NIMCALL(void, rangeCheckAnalysis__icZdce_u2364)(tyObject_AliveContext__aH9b1WgJ8tkMKZF7vl3FOBw* c_p0, tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg g_p1, tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w* tree_p2, NI n_p3);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg, loadTypeKind__icZdce_u2085)(tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig t_p0, tyObject_AliveContext__aH9b1WgJ8tkMKZF7vl3FOBw* c_p1, tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg g_p2, tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg toSkip_p3);
N_LIB_PRIVATE N_NIMCALL(tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA, translateId__icZic_u21415)(tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig id_p0, tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg g_p1, NI thisModule_p2, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p3);
N_LIB_PRIVATE N_NIMCALL(tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ*, X5BX5D___icZdce_u2147)(tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw* t_p0, NI32 key_p1);
static N_INLINE(tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig, X5BX5D___icZdce_u2298)(tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig* s_p0, NI s_p0Len_0, NI i_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig, findType__icZpacked95ast_u1025)(tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w* tree_p0, NI n_p1);
static N_INLINE(NI, firstSon__icZpacked95ast_u1217)(NI n_p0);
N_LIB_PRIVATE N_NIMCALL(void, requestCompilerProc__icZdce_u1936)(tyObject_AliveContext__aH9b1WgJ8tkMKZF7vl3FOBw* c_p0, tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg g_p1, NimStringV2 name_p2);
N_LIB_PRIVATE N_NIMCALL(tyTuple__Ll5iolPASSzOEheeSNjmiw*, X5BX5D___icZdce_u1993)(tyObject_Table__t60gWhquDic6PI6CgxHkgw* t_p0, NimStringV2 key_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isExportedToC__icZdce_u26)(tyObject_AliveContext__aH9b1WgJ8tkMKZF7vl3FOBw* c_p0, tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg g_p1, NI32 symId_p2);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___icZdce_u204)(tyObject_Table__t60gWhquDic6PI6CgxHkgw* t_p0, NimStringV2 key_p1, tyTuple__Ll5iolPASSzOEheeSNjmiw val_p2);
static N_INLINE(NimStringV2*, X5BX5D___icZic_u178)(tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA* t_p0, NU32 litId_p1);
static N_INLINE(NI, span__icZpacked95ast_u1117)(tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w* tree_p0, NI pos_p1);
static N_INLINE(NIM_BOOL, isAtom__icZpacked95ast_u541)(tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w* tree_p0, NI pos_p1);
N_LIB_PRIVATE N_NIMCALL(void, followNow__icZdce_u2446)(tyObject_AliveContext__aH9b1WgJ8tkMKZF7vl3FOBw* c_p0, tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg g_p1);
static N_INLINE(tyTuple__jYR27AKllNE6EvJCKQs1WA, pop__icZdce_u2452)(tySequence__MboA857W9b3olvEyCWLQeEg* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___icZdce_u1915)(tyTuple__jYR27AKllNE6EvJCKQs1WA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZdce_u2467)(tySequence__MboA857W9b3olvEyCWLQeEg* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___nilcheck_u1423)(tySequence__4SBkVvm2CCxNvzruVhJR5g* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZdce_u2660)(tyObject_AliveContext__aH9b1WgJ8tkMKZF7vl3FOBw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZdce_u641)(tySequence__UuiPn6QjIiUTdSVwX2PZ6w dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___nilcheck_u1426)(tySequence__4SBkVvm2CCxNvzruVhJR5g dest_p0);
static N_INLINE(NIM_BOOL, nimDecRefIsLast)(void* p_p0);
static N_INLINE(NI, minuspercent___system_u805)(NI x_p0, NI y_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___idents_u274)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, nimRawDispose)(void* p_p0, NI alignment_p1);
static N_INLINE(NIM_BOOL, nimDecRefIsLastDyn)(void* p_p0);
N_LIB_PRIVATE N_NIMCALL(void, unregisterCycle__system_u3127)(tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___options_u1751)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZdce_u2604)(tySequence__MboA857W9b3olvEyCWLQeEg dest_p0);
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__uErKJhkx70jmGDNtVJTUvA_2 = {
0x10, 0xa9, 0x80, 0x00, 0x00, 0xe0, 0x80, 0x00,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__uErKJhkx70jmGDNtVJTUvA_3 = { 21 | NIM_STRLIT_FLAG, "raiseRangeErrorNoArgs" };
static const NimStringV2 TM__uErKJhkx70jmGDNtVJTUvA_4 = {21, (NimStrPayload*)&TM__uErKJhkx70jmGDNtVJTUvA_3};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__uErKJhkx70jmGDNtVJTUvA_5 = {
0x10, 0xa9, 0x90, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__uErKJhkx70jmGDNtVJTUvA_6 = { 16 | NIM_STRLIT_FLAG, "raiseRangeErrorU" };
static const NimStringV2 TM__uErKJhkx70jmGDNtVJTUvA_7 = {16, (NimStrPayload*)&TM__uErKJhkx70jmGDNtVJTUvA_6};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__uErKJhkx70jmGDNtVJTUvA_8 = { 16 | NIM_STRLIT_FLAG, "raiseRangeErrorF" };
static const NimStringV2 TM__uErKJhkx70jmGDNtVJTUvA_9 = {16, (NimStrPayload*)&TM__uErKJhkx70jmGDNtVJTUvA_8};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__uErKJhkx70jmGDNtVJTUvA_10 = { 16 | NIM_STRLIT_FLAG, "raiseRangeErrorI" };
static const NimStringV2 TM__uErKJhkx70jmGDNtVJTUvA_11 = {16, (NimStrPayload*)&TM__uErKJhkx70jmGDNtVJTUvA_10};
extern NIM_BOOL nimInErrorMode__system_u4143;
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a_p0, v_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1) {
	nimSetMem__system_u2172(p_p0, ((int)0), size_p1);
}
static N_INLINE(NI, len__icZpacked95ast_u767)(tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w* tree_p0) {
	NI result;
	NI T1_;
	T1_ = (*tree_p0).nodes.len;
	result = T1_;
	return result;
}
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void) {
	NIM_BOOL* result;
	result = (&nimInErrorMode__system_u4143);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, followLater__icZdce_u1695)(tyObject_AliveContext__aH9b1WgJ8tkMKZF7vl3FOBw* c_p0, tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg g_p1, NI module_p2, NI32 item_p3) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		NI32 body_1;
		tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw* T6_;
		T3_ = (NIM_BOOL)0;
		T3_ = containsOrIncl__astyaml_u223((&(*c_p0).alive.p->data[module_p2]), ((NI) (item_p3)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!(T3_)) goto LA4_;
		T6_ = (tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw*)0;
		T6_ = X5BX5D___icZic_u300((&g_p1.pm.p->data[module_p2].fromDisk.syms), item_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		body_1 = (*T6_).ast;
		{
			tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ opt_1;
			tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw* T11_;
			tyTuple__jYR27AKllNE6EvJCKQs1WA T18_;
			if (!!((body_1 == ((NI32)-1)))) goto LA9_;
			T11_ = (tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw*)0;
			T11_ = X5BX5D___icZic_u300((&g_p1.pm.p->data[module_p2].fromDisk.syms), item_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			opt_1 = (*T11_).options;
			{
				tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw* T14_;
				NI T17_;
				T14_ = (tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw*)0;
				T14_ = X5BX5D___icZic_u300((&g_p1.pm.p->data[module_p2].fromDisk.syms), item_p3);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				if (!((*T14_).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || (*T14_).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13) || (*T14_).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14) || (*T14_).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15) || (*T14_).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16) || (*T14_).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)17) || (*T14_).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18))) goto LA15_;
				T17_ = (NI)0;
				T17_ = ithSon__icZpacked95ast_u1185((&g_p1.pm.p->data[module_p2].fromDisk.bodies), ((NI) (body_1)), ((NI)6));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				body_1 = ((NI32) (T17_));
			}
LA15_: ;
			T18_.Field0 = module_p2;
			T18_.Field1 = opt_1;
			T18_.Field2 = ((NI) (body_1));
			add__icZdce_u1890((&(*c_p0).stack), T18_);
		}
LA9_: ;
	}
LA4_: ;
	}BeforeRet_: ;
}
static N_INLINE(tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w*, X5BX5D___icZpacked95ast_u773)(tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w* tree_p0, NI i_p1) {
	tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w* result;
	result = (&(*tree_p0).nodes.p->data[i_p1]);
	return result;
}
static N_INLINE(void, nextChild__icZpacked95ast_u798)(tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w* tree_p0, NI* pos_p1) {
	{
		if (!(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23) < ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw) ((NU32)((*tree_p0).nodes.p->data[(*pos_p1)].x & ((NU32)255)))))) goto LA3_;
		(*pos_p1) += ((NI) ((NU32)((NU32)((*tree_p0).nodes.p->data[(*pos_p1)].x) >> (NU32)(((NU32)8) & (32 - 1)))));
	}
	goto LA1_;
LA3_: ;
	{
		(*pos_p1) += ((NI)1);
	}
LA1_: ;
}
static N_INLINE(tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig, X5BX5D___icZdce_u2298)(tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig* s_p0, NI s_p0Len_0, NI i_p1) {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig result;
	result = s_p0[(NI)(s_p0Len_0 - i_p1)];
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg, loadTypeKind__icZdce_u2085)(tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig t_p0, tyObject_AliveContext__aH9b1WgJ8tkMKZF7vl3FOBw* c_p1, tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg g_p2, tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg toSkip_p3) {
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg result;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA t2_1;
	tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ* T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)0;
	t2_1 = translateId__icZic_u21415(t_p0, g_p2, (*c_p1).thisModule, (*c_p1).decoder.config);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = (tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ*)0;
	T1_ = X5BX5D___icZdce_u2147((&g_p2.pm.p->data[t2_1.module].fromDisk.types), t2_1.item);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = (*T1_).kind;
	{
		while (1) {
			tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ* T4_;
			tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig T5_;
			tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ* T6_;
			if (!((toSkip_p3[(NU)((result))>>3] &(1U<<((NU)((result))&7U)))!=0)) goto LA3;
			T4_ = (tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ*)0;
			T4_ = X5BX5D___icZdce_u2147((&g_p2.pm.p->data[t2_1.module].fromDisk.types), t2_1.item);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T5_ = X5BX5D___icZdce_u2298((((*T4_).types).p) ? ((*T4_).types.p->data) : NIM_NIL, (*T4_).types.len, ((NI)1));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			t2_1 = translateId__icZic_u21415(T5_, g_p2, ((NI) (t2_1.module)), (*c_p1).decoder.config);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T6_ = (tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ*)0;
			T6_ = X5BX5D___icZdce_u2147((&g_p2.pm.p->data[t2_1.module].fromDisk.types), t2_1.item);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			result = (*T6_).kind;
		} LA3: ;
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, firstSon__icZpacked95ast_u1217)(NI n_p0) {
	NI result;
	result = (NI)(n_p0 + ((NI)1));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, requestCompilerProc__icZdce_u1936)(tyObject_AliveContext__aH9b1WgJ8tkMKZF7vl3FOBw* c_p0, tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg g_p1, NimStringV2 name_p2) {
	tyTuple__Ll5iolPASSzOEheeSNjmiw tmpTuple_1;
	tyTuple__Ll5iolPASSzOEheeSNjmiw* T1_;
	NI module_1;
	NI32 item_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = (tyTuple__Ll5iolPASSzOEheeSNjmiw*)0;
	T1_ = X5BX5D___icZdce_u1993((&(*c_p0).compilerProcs), name_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	tmpTuple_1 = (*T1_);
	module_1 = tmpTuple_1.Field0;
	item_1 = tmpTuple_1.Field1;
	followLater__icZdce_u1695(c_p0, g_p1, module_1, item_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, rangeCheckAnalysis__icZdce_u2364)(tyObject_AliveContext__aH9b1WgJ8tkMKZF7vl3FOBw* c_p0, tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg g_p1, tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w* tree_p2, NI n_p3) {
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg dest_1;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = findType__icZpacked95ast_u1025(tree_p2, n_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	dest_1 = loadTypeKind__icZdce_u2085(T1_, (&(*c_p0)), g_p1, TM__uErKJhkx70jmGDNtVJTUvA_2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = !((((*c_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)3)))&31U)))!=0));
		if (T4_) goto LA5_;
		T4_ = (dest_1 >= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) && dest_1 <= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44));
LA5_: ;
		if (!T4_) goto LA6_;
	}
	goto LA2_;
LA6_: ;
	{
		tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg n0t_1;
		NI T9_;
		tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig T10_;
		tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg T11_;
		T9_ = (NI)0;
		T9_ = firstSon__icZpacked95ast_u1217(n_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T10_ = findType__icZpacked95ast_u1025(tree_p2, T9_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimZeroMem(T11_, sizeof(tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg));
		n0t_1 = loadTypeKind__icZdce_u2085(T10_, (&(*c_p0)), g_p1, T11_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			if (!(n0t_1 == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) || n0t_1 == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44))) goto LA14_;
			requestCompilerProc__icZdce_u1936(c_p0, g_p1, TM__uErKJhkx70jmGDNtVJTUvA_4);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA12_;
LA14_: ;
		{
			NimStringV2 raiser_1;
			NimStringV2 T17_;
			tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig T18_;
			tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg T19_;
			raiser_1.len = 0; raiser_1.p = NIM_NIL;
			T17_.len = 0; T17_.p = NIM_NIL;
			T18_ = findType__icZpacked95ast_u1025(tree_p2, n_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T19_ = (tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)0;
			T19_ = loadTypeKind__icZdce_u2085(T18_, (&(*c_p0)), g_p1, TM__uErKJhkx70jmGDNtVJTUvA_5);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			switch (T19_) {
			case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44):
			case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2):
			{
				raiser_1 = TM__uErKJhkx70jmGDNtVJTUvA_7;
			}
			break;
			case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)36) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)39):
			{
				raiser_1 = TM__uErKJhkx70jmGDNtVJTUvA_9;
			}
			break;
			default:
			{
				raiser_1 = TM__uErKJhkx70jmGDNtVJTUvA_11;
			}
			break;
			}
			requestCompilerProc__icZdce_u1936(c_p0, g_p1, raiser_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA12_: ;
	}
LA2_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___icZdce_u1262)(tyTuple__Ll5iolPASSzOEheeSNjmiw* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1 = 0;
}
static N_INLINE(NimStringV2*, X5BX5D___icZic_u178)(tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA* t_p0, NU32 litId_p1) {
	NimStringV2* result;
	NI idx_1;
	idx_1 = (NI)(((NI) (litId_p1)) - ((NI)1));
	result = (&(*t_p0).vals.p->data[idx_1]);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isExportedToC__icZdce_u26)(tyObject_AliveContext__aH9b1WgJ8tkMKZF7vl3FOBw* c_p0, tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg g_p1, NI32 symId_p2) {
	NIM_BOOL result;
	tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw* symPtr_1;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flags_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	symPtr_1 = X5BX5D___icZic_u300((&g_p1.pm.p->data[(*c_p0).thisModule].fromDisk.syms), symId_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	flags_1 = (*symPtr_1).flags;
	{
		if (!!(((flags_1 &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)28)))&63U)))!=0))) goto LA3_;
		{
			NIM_BOOL T7_;
			tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T8_;
			T7_ = (NIM_BOOL)0;
			T8_ = 0;
			T7_ = !(((262272 & flags_1) == T8_));
			if (T7_) goto LA9_;
			T7_ = ((*symPtr_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14));
LA9_: ;
			if (!T7_) goto LA10_;
			result = NIM_TRUE;
		}
		goto LA5_;
LA10_: ;
		{
			result = NIM_FALSE;
		}
LA5_: ;
		{
			NimStringV2* T17_;
			tyTuple__Ll5iolPASSzOEheeSNjmiw T18_;
			if (!((flags_1 &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)18)))&63U)))!=0)) goto LA15_;
			T17_ = (NimStringV2*)0;
			T17_ = X5BX5D___icZic_u178((&g_p1.pm.p->data[(*c_p0).thisModule].fromDisk.strings), (*symPtr_1).name);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T18_.Field0 = (*c_p0).thisModule;
			T18_.Field1 = symId_p2;
			X5BX5Deq___icZdce_u204((&(*c_p0).compilerProcs), (*T17_), T18_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA15_: ;
	}
	goto LA1_;
LA3_: ;
	{
		result = NIM_FALSE;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, aliveCode__icZdce_u2384)(tyObject_AliveContext__aH9b1WgJ8tkMKZF7vl3FOBw* c_p0, tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg g_p1, tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w* tree_p2, NI n_p3) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	switch (((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw) ((NU32)((*tree_p2).nodes.p->data[n_p3].x & ((NU32)255))))) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)0) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)4) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23):
	{
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
	{
		tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w* T3_;
		T3_ = (tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w*)0;
		T3_ = X5BX5D___icZpacked95ast_u773(tree_p2, n_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		followLater__icZdce_u1695(c_p0, g_p1, (*c_p0).thisModule, ((NI32) ((NU32)((NU32)((*T3_).x) >> (NU32)(((NU32)8) & (32 - 1))))));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)162):
	{
		tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ tmpTuple_1;
		NI n1_1;
		NI n2_1;
		NU32 m_1;
		NI32 item_1;
		tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w* T5_;
		NI otherModule_1;
		NI32 T6_;
		tmpTuple_1 = sons2__icZpacked95ast_u1125(tree_p2, n_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		n1_1 = tmpTuple_1.Field0;
		n2_1 = tmpTuple_1.Field1;
		m_1 = (NU32)((NU32)((*tree_p2).nodes.p->data[n1_1].x) >> (NU32)(((NU32)8) & (32 - 1)));
		T5_ = (tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w*)0;
		T5_ = X5BX5D___icZpacked95ast_u773(tree_p2, n2_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		item_1 = ((NI32) ((NU32)((NU32)((*T5_).x) >> (NU32)(((NU32)8) & (32 - 1)))));
		T6_ = (NI32)0;
		T6_ = toFileIndexCached__icZic_u12260((&(*c_p0).decoder), g_p1, (*c_p0).thisModule, m_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		otherModule_1 = ((NI) (T6_));
		followLater__icZdce_u1695(c_p0, g_p1, otherModule_1, item_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)82):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)83):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)98):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)132):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)125):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)121):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)116):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)117):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)118):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)119):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)120):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)113):
	{
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)99):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)100):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)101):
	{
		{
			NI son_1;
			NI pos_1;
			NI last_1;
			son_1 = (NI)0;
			pos_1 = n_p3;
			last_1 = (NI)(pos_1 + ((NI) ((NU32)((NU32)((*tree_p2).nodes.p->data[pos_1].x) >> (NU32)(((NU32)8) & (32 - 1))))));
			pos_1 += ((NI)1);
			{
				while (1) {
					if (!(pos_1 < last_1)) goto LA11;
					son_1 = pos_1;
					aliveCode__icZdce_u2384(c_p0, g_p1, tree_p2, son_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					nextChild__icZpacked95ast_u798(tree_p2, (&pos_1));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				} LA11: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)68):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)69):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)70):
	{
		rangeCheckAnalysis__icZdce_u2364(c_p0, g_p1, tree_p2, n_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)79):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)81):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)80):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)159):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)84):
	{
		{
			NIM_BOOL T16_;
			NI T17_;
			NI T19_;
			NI32 item_2;
			NI T22_;
			tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w* T23_;
			T16_ = (NIM_BOOL)0;
			T17_ = (NI)0;
			T17_ = firstSon__icZpacked95ast_u1217(n_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T16_ = (((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw) ((NU32)((*tree_p2).nodes.p->data[T17_].x & ((NU32)255)))) == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
			if (!(T16_)) goto LA18_;
			T19_ = (NI)0;
			T19_ = ithSon__icZpacked95ast_u1185(tree_p2, n_p3, ((NI)2));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T16_ = (((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw) ((NU32)((*tree_p2).nodes.p->data[T19_].x & ((NU32)255)))) == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1));
LA18_: ;
			if (!T16_) goto LA20_;
			T22_ = (NI)0;
			T22_ = firstSon__icZpacked95ast_u1217(n_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T23_ = (tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w*)0;
			T23_ = X5BX5D___icZpacked95ast_u773(tree_p2, T22_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			item_2 = ((NI32) ((NU32)((NU32)((*T23_).x) >> (NU32)(((NU32)8) & (32 - 1)))));
			{
				NIM_BOOL T26_;
				T26_ = (NIM_BOOL)0;
				T26_ = isExportedToC__icZdce_u26(c_p0, g_p1, item_2);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				if (!T26_) goto LA27_;
				followLater__icZdce_u1695(c_p0, g_p1, (*c_p0).thisModule, item_2);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA27_: ;
		}
LA20_: ;
	}
	break;
	default:
	{
		{
			NI son_2;
			NI pos_2;
			NI last_2;
			son_2 = (NI)0;
			pos_2 = n_p3;
			last_2 = (NI)(pos_2 + ((NI) ((NU32)((NU32)((*tree_p2).nodes.p->data[pos_2].x) >> (NU32)(((NU32)8) & (32 - 1))))));
			pos_2 += ((NI)1);
			{
				while (1) {
					if (!(pos_2 < last_2)) goto LA32;
					son_2 = pos_2;
					aliveCode__icZdce_u2384(c_p0, g_p1, tree_p2, son_2);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					nextChild__icZpacked95ast_u798(tree_p2, (&pos_2));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				} LA32: ;
			}
		}
	}
	break;
	}
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, isAtom__icZpacked95ast_u541)(tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w* tree_p0, NI pos_p1) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = (((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw) ((NU32)((*tree_p0).nodes.p->data[pos_p1].x & ((NU32)255)))) <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23));
	return result;
}
static N_INLINE(NI, span__icZpacked95ast_u1117)(tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w* tree_p0, NI pos_p1) {
	NI result;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = (NI)0;
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = isAtom__icZpacked95ast_u541(tree_p0, pos_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T4_) goto LA5_;
		result = ((NI)1);
	}
	goto LA2_;
LA5_: ;
	{
		result = ((NI) ((NU32)((NU32)((*tree_p0).nodes.p->data[pos_p1].x) >> (NU32)(((NU32)8) & (32 - 1)))));
	}
LA2_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___icZdce_u1915)(tyTuple__jYR27AKllNE6EvJCKQs1WA* dest_p0) {
	(*dest_p0).Field0 = 0;
	nimZeroMem((void*)(&(*dest_p0).Field1), sizeof(tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ));
	(*dest_p0).Field2 = 0;
}
static N_INLINE(tyTuple__jYR27AKllNE6EvJCKQs1WA, pop__icZdce_u2452)(tySequence__MboA857W9b3olvEyCWLQeEg* s_p0) {
	tyTuple__jYR27AKllNE6EvJCKQs1WA result;
	NI L_1;
	NI T1_;
	T1_ = (*s_p0).len;
	L_1 = (NI)(T1_ - ((NI)1));
	result = (*s_p0).p->data[L_1];
	eqwasMoved___icZdce_u1915((&(*s_p0).p->data[L_1]));
	shrink__icZdce_u2467(s_p0, (L_1));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, followNow__icZdce_u2446)(tyObject_AliveContext__aH9b1WgJ8tkMKZF7vl3FOBw* c_p0, tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg g_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		while (1) {
			NI T3_;
			tyTuple__jYR27AKllNE6EvJCKQs1WA tmpTuple_1;
			NI modId_1;
			tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ opt_1;
			NI ast_1;
			T3_ = (*c_p0).stack.len;
			if (!(((NI)0) < T3_)) goto LA2;
			tmpTuple_1 = pop__icZdce_u2452((&(*c_p0).stack));
			modId_1 = tmpTuple_1.Field0;
			opt_1 = tmpTuple_1.Field1;
			ast_1 = tmpTuple_1.Field2;
			(*c_p0).thisModule = modId_1;
			(*c_p0).options = opt_1;
			aliveCode__icZdce_u2384(c_p0, g_p1, (&g_p1.pm.p->data[modId_1].fromDisk.bodies), ast_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA2: ;
	}
	}BeforeRet_: ;
}
static N_INLINE(NI, minuspercent___system_u805)(NI x_p0, NI y_p1) {
	NI result;
	result = ((NI) ((NU)((NU64)(((NU) (x_p0))) - (NU64)(((NU) (y_p1))))));
	return result;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLast)(void* p_p0) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((NI64)((*cell_1).rc) >> (NU64)(((NI)4) & (64 - 1))) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
	}
LA3_: ;
	return result;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLastDyn)(void* p_p0) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((*cell_1).rc & ((NI)-16)) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
		{
			if (!result) goto LA13_;
			{
				if (!(((NI)0) < (*cell_1).rootIdx)) goto LA17_;
				unregisterCycle__system_u3127(cell_1);
			}
LA17_: ;
		}
LA13_: ;
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZdce_u2660)(tyObject_AliveContext__aH9b1WgJ8tkMKZF7vl3FOBw* dest_p0) {
	eqdestroy___icZdce_u641((*dest_p0).compilerProcs.data);
	eqdestroy___nilcheck_u1426((*dest_p0).alive);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLast((*dest_p0).decoder.cache);
		if (!T3_) goto LA4_;
		eqdestroy___idents_u274((&(*(*dest_p0).decoder.cache)));
		nimRawDispose((*dest_p0).decoder.cache, ((NI)8));
	}
LA4_: ;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = nimDecRefIsLastDyn((*dest_p0).decoder.config);
		if (!T8_) goto LA9_;
		eqdestroy___options_u1751((&(*(*dest_p0).decoder.config)));
		nimRawDispose((*dest_p0).decoder.config, ((NI)8));
	}
LA9_: ;
	eqdestroy___icZdce_u2604((*dest_p0).stack);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__4SBkVvm2CCxNvzruVhJR5g, computeAliveSyms__icZdce_u2535)(tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg g_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p1) {
	tySequence__4SBkVvm2CCxNvzruVhJR5g result;
	tyObject_AliveContext__aH9b1WgJ8tkMKZF7vl3FOBw c_1;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* colontmpD_;
	NI T2_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	nimZeroMem((void*)(&c_1), sizeof(tyObject_AliveContext__aH9b1WgJ8tkMKZF7vl3FOBw));
	nimZeroMem((void*)(&c_1), sizeof(tyObject_AliveContext__aH9b1WgJ8tkMKZF7vl3FOBw));
	c_1.stack.len = 0; c_1.stack.p = (tySequence__MboA857W9b3olvEyCWLQeEg_Content*) newSeqPayload(0, sizeof(tyTuple__jYR27AKllNE6EvJCKQs1WA), NIM_ALIGNOF(tyTuple__jYR27AKllNE6EvJCKQs1WA));
	nimZeroMem((void*)(&c_1.decoder), sizeof(tyObject_PackedDecoder__mXpMPUjuhwIS5ssrGM9bHWA));
	colontmpD_ = eqdup___options_u2141(conf_p1);
	c_1.decoder.config = colontmpD_;
	c_1.thisModule = ((NI)-1);
	T2_ = g_p0.pm.len;
	c_1.alive = newSeq__icZdce_u2562((T2_));
	c_1.options = (*conf_p1).options;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = g_p0.pm.len;
		colontmp_ = (NI)(T4_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(((NI)0) <= res_1)) goto LA6;
				i_1 = ((NI) (res_1));
				{
					if (!!((g_p0.pm.p->data[i_1].status == ((tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ)0)))) goto LA9_;
					c_1.thisModule = i_1;
					{
						NI p_1;
						tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w* colontmp__2;
						NI p_2;
						p_1 = (NI)0;
						colontmp__2 = (tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w*)0;
						colontmp__2 = (&g_p0.pm.p->data[i_1].fromDisk.topLevel);
						p_2 = ((NI)0);
						{
							while (1) {
								NI T14_;
								NI s_1;
								T14_ = (NI)0;
								T14_ = len__icZpacked95ast_u767((&(*colontmp__2)));
								if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
								if (!(p_2 < T14_)) goto LA13;
								p_1 = p_2;
								aliveCode__icZdce_u2384((&c_1), g_p0, (&g_p0.pm.p->data[i_1].fromDisk.topLevel), p_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
								s_1 = span__icZpacked95ast_u1117((&(*colontmp__2)), p_2);
								if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
								p_2 += s_1;
							} LA13: ;
						}
					}
				}
LA9_: ;
				res_1 -= ((NI)1);
			} LA6: ;
		}
	}
	followNow__icZdce_u2446((&c_1), g_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = c_1.alive;
	eqwasMoved___nilcheck_u1423((&c_1.alive));
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___icZdce_u2660((&c_1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
